UseValueProviderElement class

A statically parsed Provider that describes a constant expression.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
isMulti → bool
Whether this represents a multi-binding.
no setterinherited
providerType → TypeLink?
The T type of Provider<T>.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → TokenElement
Canonical URL of the source location and element name being referenced.
finalinherited
useValue → DartObject?
A reference to the constant expression or literal to generate.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object o) → bool
The equality operator.
inherited