BoundI18nMessage class

Implemented types

Constructors

BoundI18nMessage(I18nMessage value)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isBool → bool
final
isDouble → bool
final
isImmutable → bool
final
isInt → bool
final
isNullable → bool
final
isNumber → bool
final
isString → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → I18nMessage
final

Methods

accept<R, C, CO extends C>(BindingSourceVisitor<R, C> visitor, [CO? context]) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited