EmitterVisitorContext class

Constructors

EmitterVisitorContext(int _indent)

Properties

currentLineLength → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decIndent() → void
incIndent() → void
lineIsEmpty() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
popClass() → ClassStmt
print(String part, [bool newLine = false]) → void
println([String lastPart = '']) → void
pushClass(ClassStmt clazz) → void
removeEmptyLastLine() → void
toSource() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createRoot() → EmitterVisitorContext