BoundElementPropertyAst class

A binding for an element property (e.g. property='expression').

Implemented types

Constructors

BoundElementPropertyAst(String? namespace, String? name, PropertyBindingType? type, TemplateSecurityContext? securityContext, BoundValue value, String? unit, SourceSpan sourceSpan)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
namespace → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityContext → TemplateSecurityContext?
final
sourceSpan → SourceSpan
The source span from which this node was parsed.
final
type → PropertyBindingType?
final
unit → String?
final
value → BoundValue
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit<R, C, CO extends C>(TemplateAstVisitor<R, C> visitor, CO context) → R
Visit this node and possibly transform it.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited