AppViewReference class

Reference to html node created during AppView build.

Constructors

AppViewReference(CompileElement parent, int nodeIndex)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nodeIndex → int
final
parent → CompileElement
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allocate(CompileViewStorage storage, {OutputType? outputType}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toReadExpr() → ReadClassMemberExpr
toString() → String
A string representation of this object.
inherited
toWriteStmt(Expression value) → Statement

Operators

operator ==(Object other) → bool
The equality operator.
inherited