WriteNodeReferenceStmt class

An AST statement that writes the value of a NodeReference.

When visited it behaves as a DeclareVarStmt or WriteClassMemberStmt depending on the visibility of the NodeReference.

Inheritance

Constructors

WriteNodeReferenceStmt(NodeReference node, Expression? value)

Properties

hashCode → int
The hash code for this object.
no setterinherited
modifiers ↔ List<StmtModifier>
getter/setter pairinherited
name → String
finalinherited
node → NodeReference
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceReference ↔ SourceReference?
getter/setter pairinherited
type → OutputType?
finalinherited
value → Expression?
finalinherited

Methods

hasModifier(StmtModifier modifier) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visitStatement<R, C>(StatementVisitor<R, C> visitor, C context) → R
override
withValue(Expression? replacement) → WriteNodeReferenceStmt
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited