ProviderNode class

Represents a node in the dependency injection hierarchy of a view.

Constructors

ProviderNode(int start, int end, {List<ProviderInstance> providers = const [], List<ProviderNode> children = const []})

Properties

children → List<ProviderNode>
The children of this node.
final
end → int
The highest index of the range within which this provider is injectable.
final
hashCode → int
The hash code for this object.
no setterinherited
providers → List<ProviderInstance>
The providers which are available for injection from this node.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
The lowest index of the range within which this provider is injectable.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override